==> arquillian-tomee-webapp-remote-1.0.0-sources.jar: org/apache/tomee/arquillian/webapp/TomEEWebappObserver.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.apache.tomee.arquillian.webapp;

import org.apache.openejb.cdi.ThreadSingletonServiceImpl;
import org.jboss.arquillian.core.api.InstanceProducer;
import org.jboss.arquillian.core.api.annotation.Inject;
import org.jboss.arquillian.core.api.annotation.Observes;
import org.jboss.arquillian.test.spi.annotation.SuiteScoped;
import org.jboss.arquillian.test.spi.event.suite.BeforeSuite;

import javax.enterprise.inject.spi.BeanManager;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

public class TomEEWebappObserver {
    @Inject
    @SuiteScoped
    private InstanceProducer<BeanManager> beanManager;
    @Inject
    @SuiteScoped
    private InstanceProducer<Context> context;

    public void beforeSuite(@Observes BeforeSuite event) {
        beanManager.set(ThreadSingletonServiceImpl.get().getBeanManagerImpl());
        try {
            context.set(new InitialContext());
        } catch (NamingException e) {
            // no-op
        }
    }
}

==> arquillian-tomee-webapp-remote-1.6.0.1-sources.jar: org/apache/tomee/arquillian/webapp/TomEEWebappObserver.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.apache.tomee.arquillian.webapp;

import org.apache.openejb.cdi.ThreadSingletonServiceImpl;
import org.jboss.arquillian.core.api.InstanceProducer;
import org.jboss.arquillian.core.api.annotation.Inject;
import org.jboss.arquillian.core.api.annotation.Observes;
import org.jboss.arquillian.test.spi.annotation.SuiteScoped;
import org.jboss.arquillian.test.spi.event.suite.BeforeSuite;

import javax.enterprise.inject.spi.BeanManager;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

public class TomEEWebappObserver {
    @Inject
    @SuiteScoped
    private InstanceProducer<BeanManager> beanManager;
    @Inject
    @SuiteScoped
    private InstanceProducer<Context> context;

    public void beforeSuite(@Observes BeforeSuite event) {
        beanManager.set(ThreadSingletonServiceImpl.get(Thread.currentThread().getContextClassLoader()).getBeanManagerImpl());
        try {
            context.set(new InitialContext());
        } catch (NamingException e) {
            // no-op
        }
    }
}
